#OWNER: Jermiah Joseph

#DATE: 2024-05-30

#DESC: A simple readme.

#SIZE: 442368 - 2024-07-31-16:26


# An example of a python code block

```python
import numpy as np
import pandas as pd

df = pd.DataFrame(np.random.randn(10, 5), columns=['A', 'B', 'C', 'D', 'E'])
print(df)
```